        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,1,2,3,4,11,12,13,15,17,21,24,26,30,32,34,39,40,42,44,45,46,47,48';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 15 <br>5,6,7,8,9,14,16,19,20,23,25,27,37,38,41';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 12 <br>10,18,22,28,29,31,33,35,36,43,49,50';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,1,2,3,4,11,12,13,15,17,21,24,26,30,32,34,39,40,42,44,45,46,47,48';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 15 <br>5,6,7,8,9,14,16,19,20,23,25,27,37,38,41';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 12 <br>10,18,22,28,29,31,33,35,36,43,49,50';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,1,2,3,4,11,12,13,15,17,21,24,26,30,32,34,39,40,42,44,45,46,47,48';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 15 <br>5,6,7,8,9,14,16,19,20,23,25,27,37,38,41';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 12 <br>10,18,22,28,29,31,33,35,36,43,49,50';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,1,2,3,4,11,12,13,15,17,21,24,26,30,32,34,39,40,42,44,45,46,47,48';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 15 <br>5,6,7,8,9,14,16,19,20,23,25,27,37,38,41';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 12 <br>10,18,22,28,29,31,33,35,36,43,49,50';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,1,2,3,4,11,12,13,15,17,21,24,26,30,32,34,39,40,42,44,45,46,47,48';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 15 <br>5,6,7,8,9,14,16,19,20,23,25,27,37,38,41';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 12 <br>10,18,22,28,29,31,33,35,36,43,49,50';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 24 <strong>control</strong><br>0,1,2,3,4,11,12,13,15,17,21,24,26,30,32,34,39,40,42,44,45,46,47,48';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 15 <br>5,6,7,8,9,14,16,19,20,23,25,27,37,38,41';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260623 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 12 <br>10,18,22,28,29,31,33,35,36,43,49,50';}
}
